<?php
namespace EjunkieWPPlugin;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.e-junkie.com/wordpress-plugins/
 * @since      1.0.0
 *
 * @package    E_Junkie
 * @subpackage E_Junkie/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    E_Junkie
 * @subpackage E_Junkie/admin
 * @author     E-Junkie <swastik@e-junkie.com>
 */
class E_Junkie_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {
		
		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in E_Junkie_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The E_Junkie_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/e-junkie-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in E_Junkie_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The E_Junkie_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_script( $this->plugin_name."_Jquery_Validation", plugin_dir_url( __FILE__ ) . 'js/jquery.validate.js', array( 'jquery' ), $this->version, false );
		wp_enqueue_script( $this->plugin_name."_Jquery_Additional_Validation", plugin_dir_url( __FILE__ ) . 'js/additional-methods.js', array( 'jquery' ), $this->version, false );
		
		wp_enqueue_script( $this->plugin_name."_theme_editor", plugin_dir_url( __FILE__ ) . 'them_editor/ace.js', '', $this->version, false );
		
		wp_enqueue_script( $this->plugin_name."_e-junkie_common", plugin_dir_url( __FILE__ ) . 'js/e-junkie-admin.js', array( 'jquery' ), $this->version, false );
		
	

	}
	
	
	/**
	* Register the administration menu for this plugin into the WordPress Dashboard menu.
	*
	* @since 1.0.0
	*/
	 
	public function add_plugin_admin_menu() {
		
		add_menu_page( 'E-junkie', 'E-junkie', 'manage_options', $this->plugin_name, array($this, 'display_options'),plugin_dir_url(__FILE__) . 'images/e-junkie.png');
		
		add_submenu_page( $this->plugin_name,'Settings', 'Settings', 'manage_options', $this->plugin_name, array($this, 'display_options'));
		
		add_submenu_page( $this->plugin_name,'Shop Theme Editor', 'Shop Theme Editor', 'manage_options', $this->plugin_name."/theme_editor", array($this, 'theme_editor'));
		
		
		//add_submenu_page( $this->plugin_name,'Button Code', 'Button Code', 'manage_options', $this->plugin_name."/button_code", array($this, 'button_code'));
		
	}
	
	public function options_update() {
	
    register_setting($this->plugin_name, $this->plugin_name);
	register_setting($this->plugin_name."_theme",$this->plugin_name."_theme",array($this,'update_template'));
	
	register_setting($this->plugin_name."_button_code",$this->plugin_name."_button_code",array($this,'set_button_code'));
	flush_rewrite_rules();
	}
	
	public function set_button_code($input){
		
		return false;
		
	}
	
	
	public function update_template($input) { 
	
	
	
	if($input["shop_template"]){
		
		file_put_contents(plugin_dir_path( __DIR__ )."public/theme/default/shop.ej",$input["shop_template"]);
		file_put_contents(plugin_dir_path( __DIR__ )."admin/partials/theme_editor_current/shop.ej",$input["shop_template"]);
		
	}
	if($input["product_template"]){
		
		file_put_contents(plugin_dir_path( __DIR__ )."public/theme/default/product.ej",$input["product_template"]);
		file_put_contents(plugin_dir_path( __DIR__ )."admin/partials/theme_editor_current/product.ej",$input["product_template"]);
		
	}
	
	

	return false;
	}
	
	
	
	/**
	* Render the settings page for this plugin.
	*
	* @since 1.0.0
	*/
	 
	public function display_options() {
		
		
		include_once( 'partials/options.php' );
	}
	
	/**
	* Render the settings page for this plugin.
	*
	* @since 1.0.0
	*/
	 
	public function theme_editor() {
		
		
		include_once( 'partials/theme_editor.php' );
	}
	
	
	public function button_code(){
		
	 include_once( 'partials/button_code.php' );	
		
	}
		
	/**
	* Creates a new custom post type
	*
	* @since 1.0.0
	* @access public
	* @uses register_post_type()
	*/
	public static function e_junkie_custom_post_type() {
	$options = get_option('e-junkie');
	$cap_type = 'page';
	
	$cpt_name = 'e-junkie';
	$opts['can_export'] = TRUE;
	$opts['capability_type'] = $cap_type;
	$opts['description'] = '';
	$opts['exclude_from_search'] = FALSE;
	$opts['has_archive']=TRUE;
	$opts['hierarchical'] = TRUE;
	$opts['map_meta_cap'] = TRUE;
	$opts['menu_icon'] = 'dashicons-businessman';
	$opts['menu_position'] = 25;
	$opts['public'] = TRUE;
	$opts['publicly_querable'] = TRUE;
	$opts['query_var'] = TRUE;
	$opts['register_meta_box_cb'] = '';
	$opts['rewrite'] = array("slug"=>(isset($options['shop']) && !empty($options['shop'])) ? $options['shop'] : 'shop','with_front' => true);
	
	$opts['show_in_admin_bar'] = FALSE;
	$opts['show_in_menu'] = FALSE;
	$opts['show_in_nav_menu'] = FALSE;
	register_post_type( strtolower( $cpt_name ), $opts );
	flush_rewrite_rules();
	} // new_cpt_job()
	
	public function add_action_links( $links ) {
	$settings_link = array(
		'<a href="' . admin_url( 'admin.php?page=' . $this->plugin_name ) . '">' . __('Settings', $this->plugin_name) . '</a>',
	);
	return array_merge( $settings_link, $links );
}
 

}
