<?php
namespace EjunkieWPPlugin;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.e-junkie.com/wordpress-plugins/
 * @since      1.0.0
 *
 * @package    E_Junkie
 * @subpackage E_Junkie/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    E_Junkie
 * @subpackage E_Junkie/public
 * @author     E-Junkie <swastik@e-junkie.com>
 */
class E_Junkie_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in E_Junkie_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The E_Junkie_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		$options = get_option($this->plugin_name);
		
		$theme=($options['theme']!="")?$options['theme']:"default";
		
		/*
		trash - not required in plugin
		wp_enqueue_style( $this->plugin_name."bulma.min.css", "https://cdnjs.cloudflare.com/ajax/libs/bulma/0.7.1/css/bulma.min.css", array(), '0.7.1', 'all' );
		wp_enqueue_style( $this->plugin_name."ionicons", "https://unpkg.com/ionicons@4.3.0/dist/css/ionicons.min.css", array(), '4.3.0', 'all' );
		wp_enqueue_style( $this->plugin_name."gfontLato", "https://fonts.googleapis.com/css?family=Lato:300,400,700,900", array(), '', 'all' );
		wp_enqueue_style( $this->plugin_name."gfontRoboto", "https://fonts.googleapis.com/css?family=Roboto:300,400,500,700", array(), '', 'all' );
		wp_enqueue_style( $this->plugin_name."gfontHindiSiliguri", "https://fonts.googleapis.com/css?family=Hind+Siliguri:300,400,500,600,700", array(), '', 'all' );
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . "css/$theme/common.css", array(), $this->version, 'all' );
		*/
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in E_Junkie_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The E_Junkie_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		 
		$options = get_option($this->plugin_name);
		
		$theme=($options['theme']!="")?$options['theme']:"default";
		
		wp_enqueue_script( $this->plugin_name."boxfbn", "https://www.e-junkie.com/ecom/box.js?wp", array('jquery'), $this->version, false );
		/*
		trash - not required in plugin
		wp_enqueue_script( $this->plugin_name."common", plugin_dir_url( __FILE__ ) . "js/$theme/common.js", array( 'jquery' ), $this->version, false );
		*/

	}
	
	function shop_template($page_template) {
		
	
	
	$options = get_option($this->plugin_name);
	
	//$current_url=$_SERVER['REQUEST_SCHEME']."://".$_SERVER['HTTP_HOST'].$_SERVER['REQUEST_URI'];
	$current_url=(isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off' ? 'https' : 'http')."://".$_SERVER['HTTP_HOST'].$_SERVER['REQUEST_URI'];
	
	$URI_PARTS=explode("/",trim(str_replace(site_url(),"",$current_url),"/"));
	
		if ( isset($URI_PARTS[0]) && !empty($URI_PARTS[0]) && $URI_PARTS[0]==$options['shop'] ) {
			
			$page_template = plugin_dir_path(__FILE__) . 'partials/shop.php';
			
						
		}
		
		return $page_template;

	}
	

	
	
}
